fakeservice

package
v0.35.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2026 License: Unlicense Imports: 2 Imported by: 0

Documentation

Overview

Package fakeservice contains fake implementations of interfaces from package service.

It is recommended to fill all methods that shouldn't be called with:

panic(testutil.UnexpectedCall(arg1, arg2))

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Refresher added in v0.31.2

type Refresher struct {
	OnRefresh func(ctx context.Context) (err error)
}

Refresher is the service.Refresher for tests.

func (*Refresher) Refresh added in v0.31.2

func (r *Refresher) Refresh(ctx context.Context) (err error)

Refresh implements the service.Refresher interface for *Refresher.

type Service

type Service struct {
	OnStart    func(ctx context.Context) (err error)
	OnShutdown func(ctx context.Context) (err error)
}

Service is the service.Interface for tests.

func (*Service) Shutdown

func (s *Service) Shutdown(ctx context.Context) (err error)

Shutdown implements the service.Interface interface for *Service.

func (*Service) Start

func (s *Service) Start(ctx context.Context) (err error)

Start implements the service.Interface interface for *Service.

Jump to