Documentation
¶
Overview ¶
Package fakeservice contains fake implementations of interfaces from package service.
It is recommended to fill all methods that shouldn't be called with:
panic(testutil.UnexpectedCall(arg1, arg2))
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Refresher ¶ added in v0.31.2
Refresher is the service.Refresher for tests.
Click to show internal directories.
Click to hide internal directories.